@@ -82,6 +82,8 @@ class PluginManager(QObject):
         @keyparam develPlugin filename of a plugin to be loaded for
             development (string)
         @exception PluginPathError raised to indicate an invalid plug-in path
+        @exception PluginModulesError raised to indicate the absence of
+            plug-in modules
         """
         super(PluginManager, self).__init__(parent)
         
@@ -337,6 +339,8 @@ class PluginManager(QObject):
         @param reload_ flag indicating to reload the module (boolean)
         @exception PluginLoadError raised to indicate an issue loading
             the plug-in
+        @exception PluginPy2IncompatibleError raised to indicate the Python 2
+            incompatibility of a plug-in
         """
         try:
             fname = "{0}.py".format(os.path.join(directory, name))
