@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -336,17 +336,17 @@ class HgBookmarksListDialog(QDialog, Ui_HgBookmarksListDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(inputTxt)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
